@@ -10,6 +10,8 @@ import tushare as ts
 from ..config import TUSHARE_TOKEN
 
 ts.set_token(TUSHARE_TOKEN)
+# 用完后清空，防止被客户端获取
+del TUSHARE_TOKEN
 pro = ts.pro_api()
 
 __path__ = []
@@ -25,6 +27,10 @@ def set_token(token):
     pass
 
 
+def get_token():
+    return ""
+
+
 def pro_api(token='', timeout=30):
     # 防止用户调用到了pro.pro_api
     pass
